*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=c:\workshop\ws115\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*;
*  Include recent version of the ExcelXP ODS tagset.
*;

%inc "&SAMPDIR.ExcelXP.sas";

*;
*  Include the macro (XLXP2SAS) to import Excel XML to SAS tables.
*;

%inc "&SAMPDIR.LoadXL.sas";

*  Create the SUGI31 style;

proc template;
  define style styles.SUGI31;
    parent = styles.Journal;

    /*****************************************************************************
      Use approximate "SUGI reddish brown" cx993300 for some foreground elements  
      Use black for other foreground elements
      Use approximate "SUGI tan" cxffcc99 for some background elements
    *****************************************************************************/

    replace colors /
      'docbg'     = cxFFFFFF
      'contentbg' = cxFFFFFF
      'contentfg' = cx000000
      'titlefg'   = _undef_
      'link2'     = cx0066AA
      'link1'     = cx004488
      'bg5'       = cxFFFFFF
      'bg4'       = cxFFFFFF
      'fg4'       = cx000000
      'bg3'       = cxFFFFFF
      'fg3'       = cx000000
      'bg2'       = cxffcc99   /*  Header and Row Header cells  */
      'bgA1'      = cxFFFFFF
      'fgA1'      = cxff0000   /*  Border lines  */
      'fg2'       = cx993300   /*  Header and Row Header cells  */
      'fg'        = cx993300;  /*  Titles and Footnotes  */

/*  Redefine some characteristics of some of the standard styles  */

    style table from table /
      borderwidth = 0;

    style header from header /
      just              = center
      font_weight       = bold
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 0;

    style rowheader from rowheader /
      font_weight = bold;

/*  Controls border lines of some Header cells  */

    style header_r_border from header /
      just              = center
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Controls border lines of the TABULATE box cell  */

    style header_box from header /
      just              = center
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Controls border lines of some Row Header cells  */

    style rowheader_r_border from rowheader /
      bordertopwidth    = 0
      borderbottomwidth = 0
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Assigns an Excel format to certain Data cells  */

    style data_z8 from data /
      tagattr='format:00000000';

  end;
run; quit;

options nocenter;

title '&CAdverse Event Data by Trial';
footnote '&LPrinted &D&RPage &P of &N';

ods listing close;
ods tagsets.ExcelXP path="&SAMPDIR" file='aedata.xml' style=SUGI31;

  ods tagsets.ExcelXP options(sheet_name='Data - Trial 1'
     width_fudge='0.7'
     frozen_headers='2' autofilter='all'
     orientation='landscape' row_repeat='1-2');

  proc print data=sample.aedata noobs label split='*';
    by protocol;
    where protocol eq 'ABC 123';
    id patient;
    id visit / style=rowheader_r_border style(header)=header_r_border;
    var aecode / style(data)=data_z8;
    var aetext--treat;
    label protocol  = 'Protocol Identifier'
          patient   = 'Patient*Identifier'
          visit     = 'Visit*Identifier'
          aecode    = '*Code'
          aetext    = '*Preferred Term'
          aesev     = '*Severity'
          frequency = '*Frequency'
          aesevc    = '*Severity'
          treat     = '*Treatment';
  run; quit;

  ods tagsets.ExcelXP options(sheet_name='Data - Trial 2'
     width_fudge='0.7'
     frozen_headers='2' autofilter='all'
     orientation='landscape' row_repeat='1-2');

  proc print data=sample.aedata noobs label split='*';
    by protocol;
    where protocol eq 'XYZ 987';
    id patient;
    id visit / style=rowheader_r_border style(header)=header_r_border;
    var aecode / style(data)=data_z8;
    var aetext--treat;
    label protocol  = 'Protocol Identifier'
          patient   = 'Patient*Identifier'
          visit     = 'Visit*Identifier'
          aecode    = '*Code'
          aetext    = '*Preferred Term'
          aesev     = '*Severity'
          frequency = '*Frequency'
          aesevc    = '*Severity'
          treat     = '*Treatment';
  run; quit;

  ods tagsets.ExcelXP options(sheet_name='Summary - Trial 1'
     width_fudge='0.75'
     absolute_column_width='18, 8, 8'
     frozen_headers='no' autofilter='none'
     orientation='portrait' row_repeat='none');

  proc tabulate data=sample.aedata;
    by protocol;
    where protocol eq 'ABC 123';
    var aesev;
    class aetext;
    class aesevc / style=rowheader_r_border;
    classlev aesevc / style=rowheader_r_border;
    table aetext*aesevc,aesev*pctn / box={label='' style=header_box};
    keyword all pctn;
    keylabel pctn='Percent';
  run; quit;

  ods tagsets.ExcelXP options(sheet_name='Summary - Trial 2'
     width_fudge='0.75'
     absolute_column_width='18, 8, 8'
     frozen_headers='no' autofilter='none'
     orientation='portrait' row_repeat='none');

  proc tabulate data=sample.aedata;
    by protocol;
    where protocol eq 'XYZ 987';
    var aesev;
    class aetext;
    class aesevc / style=rowheader_r_border;
    classlev aesevc / style=rowheader_r_border;
    table aetext*aesevc,aesev*pctn / box={label='' style=header_box};
    keyword all pctn;
    keylabel pctn='Percent';
  run; quit;
ods tagsets.ExcelXP close;