*  Directory for SAS code, data and output - remember trailing slash;

%let SAMPDIR=c:\workshop\ws115\;

*  Library containing the sample data;

libname sample "&SAMPDIR" access=read;

*  Library to store styles and tagsets;

libname mylib "&SAMPDIR";

*  Set the ODS search path for styles and tagsets;

ods path mylib.tmplmst(update)
         sashelp.tmplmst(read);

*;
*  Include recent version of the ExcelXP ODS tagset.
*;

%include "&SAMPDIR.ExcelXP.sas";

*;
*  Include the macro (XLXP2SAS) to import Excel XML to SAS tables.
*;

%include "&SAMPDIR.LoadXL.sas";

*  Create the SUGI31 style;

proc template;
  define style styles.SUGI31;
    parent = styles.Journal;

    /*****************************************************************************
      Use approximate "SUGI reddish brown" cx993300 for some foreground elements  
      Use black for other foreground elements
      Use approximate "SUGI tan" cxffcc99 for some background elements
    *****************************************************************************/

    replace colors /
      'docbg'     = cxFFFFFF
      'contentbg' = cxFFFFFF
      'contentfg' = cx000000
      'titlefg'   = _undef_
      'link2'     = cx0066AA
      'link1'     = cx004488
      'bg5'       = cxFFFFFF
      'bg4'       = cxFFFFFF
      'fg4'       = cx000000
      'bg3'       = cxFFFFFF
      'fg3'       = cx000000
      'bg2'       = cxffcc99   /*  Header and Row Header cells  */
      'bgA1'      = cxFFFFFF
      'fgA1'      = cxff0000   /*  Border lines  */
      'fg2'       = cx993300   /*  Header and Row Header cells  */
      'fg'        = cx993300;  /*  Titles and Footnotes  */

/*  Redefine some characteristics of some of the standard styles  */

    style table from table /
      borderwidth = 0;

    style header from header /
      just              = center
      font_weight       = bold
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 0;

    style rowheader from rowheader /
      font_weight = bold;

/*  Controls border lines of some Header cells  */

    style header_r_border from header /
      just              = center
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Controls border lines of the TABULATE box cell  */

    style header_box from header /
      just              = center
      bordertopwidth    = 3
      borderbottomwidth = 3
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Controls border lines of some Row Header cells  */

    style rowheader_r_border from rowheader /
      bordertopwidth    = 0
      borderbottomwidth = 0
      borderleftwidth   = 0
      borderrightwidth  = 3;

/*  Assigns an Excel format to certain Data cells  */

    style data_z8 from data /
      tagattr='format:00000000';

  end;
run; quit;